==> jute-0.0.23.tgz: package/jute/actions.js <==
/*
Copyright (c) 2011, Yahoo! Inc.
All rights reserved.

Redistribution and use of this software in source and binary forms, 
with or without modification, are permitted provided that the following 
conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.

* Redistributions in binary form must reproduce the above
  copyright notice, this list of conditions and the
  following disclaimer in the documentation and/or other
  materials provided with the distribution.

* Neither the name of Yahoo! Inc. nor the names of its
  contributors may be used to endorse or promote products
  derived from this software without specific prior
  written permission of Yahoo! Inc.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS 
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED 
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


module.exports = {

    Create: function(hub, common) {
        // Javascript is single threaded!  We don't have to worry about concurrency!
        var cache = { browsers: {}, tests_to_run: [] };
            glob = require('glob'),
            path = require('path'),
            actions = glob.globSync(path.join(__dirname, 'actions/', '*.js'));

        // Suck in all available actions
        actions.forEach(function(action) {
            var act = require(action);
            act.Create && act.Create(hub, common, glob);
        });

        hub.addListener('action', function(action, req, res) {
            hub.once('pruneDone', function(redirect) {
                if (redirect) {
                    // done
                    res.end(JSON.stringify({ redirect_run_tests: '/jute_docs/run_tests.html' }));
                } else {
                    // keep party going
                    hub.emit('action:' + action, req, res, cache);
                }

            });
            hub.emit('action:prune', action, req, res, cache);
        });
    }
};

==> jute-0.0.24.tgz: package/jute/actions.js <==
/*
Copyright (c) 2011, Yahoo! Inc.
All rights reserved.

Redistribution and use of this software in source and binary forms, 
with or without modification, are permitted provided that the following 
conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.

* Redistributions in binary form must reproduce the above
  copyright notice, this list of conditions and the
  following disclaimer in the documentation and/or other
  materials provided with the distribution.

* Neither the name of Yahoo! Inc. nor the names of its
  contributors may be used to endorse or promote products
  derived from this software without specific prior
  written permission of Yahoo! Inc.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS 
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED 
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


module.exports = {

    Create: function(hub, common) {
        // Javascript is single threaded!  We don't have to worry about concurrency!
        var glob = require('glob'),
            path = require('path'),
            actions = glob.globSync(path.join(__dirname, 'actions/', '*.js'));

        // Suck in all available actions
        actions.forEach(function(action) {
            var act = require(action);
            act.Create && act.Create(hub, common, glob);
        });

        hub.addListener('action', function(action, req, res) {
            hub.once('pruneDone', function(redirect) {
                if (redirect) {
                    // done
                    res.end(JSON.stringify({ redirect_run_tests: '/jute_docs/run_tests.html' }));
                } else {
                    // keep party going
                    hub.emit('action:' + action);
                }

            });
            hub.emit('action:prune', action);
        });
    }
};
